@@ -61,14 +61,48 @@ typedef struct __font_t
 	double		ttsize;
 } font_t;
 
+struct __node_t;
+
 typedef struct __color_t
 {
 	int	r;
 	int	g;
 	int	b;
 	int	id;
+	struct __node_t	*node;
 } color_t;
 
+typedef struct __colorlist_t
+{
+	int	n;
+	color_t	*clrs;
+} colorlist_t;
+
+typedef struct __node_t
+{
+	int		key;
+	int		op;
+	char		*content;
+	struct __node_t	*tcase;
+	struct __node_t	*fcase;
+	union {
+		char	*str;
+		color_t	clr;
+	} value;
+} node_t;
+
+typedef struct __stringlist_t
+{
+	int	n;
+	char	**strs;
+} stringlist_t;
+
+typedef struct __condstring_t
+{
+	char	*str;
+	node_t	*node;
+} condstring_t;
+
 typedef struct __config_t
 {
 	char	*cvsroot;
@@ -110,14 +144,15 @@ typedef struct __config_t
 	int	rev_rspace;
 	int	rev_tspace;
 	int	rev_bspace;
-	char	*rev_text;
+	condstring_t	rev_idtext;
+	condstring_t	rev_text;
 	color_t	rev_text_color;
 	font_t	rev_text_font;
 	int	rev_maxtags;
 
-	color_t	merge_color;
-	char	*merge_from;
-	char	*merge_to;
+	colorlist_t	merge_color;
+	stringlist_t	merge_from;
+	stringlist_t	merge_to;
 	int	merge_findall;
 	int	merge_front;
 	int	merge_nocase;
