@@ -69,6 +69,7 @@ typedef struct __merge_t
 	tag_revision_e	type;
 	tag_revision_t	to;		/* This tag/revision is destination of a merge */
 	tag_revision_t	from;		/* This tag/revision is origin of a merge */
+	int		clr;		/* Color reference for multiple regex match statements */
 } merge_t;
 
 typedef struct __idrev_t
@@ -164,6 +165,7 @@ typedef struct __revision_t	/* Logical revision structure */
 	dtext_t		*dtext;
 	rev_t		*rev;		/* Shortcut to delta->rev */
 	char		*revtext;	/* Expanded text to draw */
+	char		*revidtext;	/* Expanded ID text to draw (normally revision number) */
 	branch_t	*branch;	/* The branch this revision belongs to */
 	branch_t	**branches;	/* Branches from this revision */
 	int		nbranches;
@@ -172,6 +174,7 @@ typedef struct __revision_t	/* Logical revision structure */
 	int		w, h;		/* BBox width/height */
 	int		cx, y;		/* BBox center-top position */
 	int		stripped;	/* Set if we jumped revisions due to strip_untagged */
+	int		mergetarget;	/* Set if a cvsnt mergepoint starts/ends here */
 } revision_t;
 
 typedef struct __rcsfile_t
